Supplementary API.
Supplementary API.
(between? x lower upper)Checks whether lower <= x <= upper is true.
Checks whether `lower <= x <= upper` is true.
(effect-on-ineq proc suppl)Takes a parameterless proc, presumably for side-effects, and a
parameterless suppl, and returns a new parameterless function that executes
proc the first time and when (suppl) not= the previously cached value.
Takes a parameterless `proc`, presumably for side-effects, and a parameterless `suppl`, and returns a new parameterless function that executes `proc` the first time and when (suppl) not= the previously cached value.
Specifies a type that can handle an alternative operation.
Specifies a type that can handle an alternative operation.
(else this f)Takes f as the alternative operation.
Takes `f` as the alternative operation.
(fetch url)(fetch url opts)Function pipeline to perform a JavaScript fetch to url with an opts map
to configure the request.
The pipeline can be invoked like this:
(-> (fetch "https://site.io" {:method "GET"})
(then #(println "The jso:" %))
(else #(println "Network error:" %)))
The else clause is mandatory as it evaluates the pipeline and returns nil.
Function pipeline to perform a JavaScript fetch to `url` with an `opts` map
to configure the request.
The pipeline can be invoked like this:
```
(-> (fetch "https://site.io" {:method "GET"})
(then #(println "The jso:" %))
(else #(println "Network error:" %)))
```
The else clause is mandatory as it evaluates the pipeline and returns nil.(find-first pred coll)Returns the first item from coll that matches the given pred.
Returns the first item from `coll` that matches the given `pred`.
(slice start endx coll)Retrieves a sequence from the item number start to number endx
exclusive, from coll.
Retrieves a sequence from the item number `start` to number `endx` exclusive, from `coll`.
Specifies a type that can handle a primary operation.
Specifies a type that can handle a primary operation.
(then this f)Takes f as the primary operation.
Takes `f` as the primary operation.
(throws? f)Invokes the provided f to check whether it throws an exception.
Invokes the provided `f` to check whether it throws an exception.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |